==> haskell-blaze-markup-0.8.3.0-112.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8
key:                  blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  d0567d74a2fc8eca82edcbf200b10e50
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.3.0-113-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9
key:                  blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  a7924d09440fd9fc41b67e92399830c5
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
